@@ -12,7 +12,6 @@ import logging
 
 logger = logging.getLogger('djangoldp')
 
-
 MODEL_MODIFICATION_USER_FIELD = 'modification_user'
 STATUS_CHOICES = [
     ('Public', 'Public'),
@@ -20,7 +19,7 @@ STATUS_CHOICES = [
     ('Archived', 'Archived'),
 ]
 
-circle_fields = ["@id", "name", "subtitle", "description", "creationDate", "status", "owner", "jabberID", "jabberRoom", "members"]
+circle_fields = ["@id", "name", "subtitle", "description", "creationDate", "status", "owner", "jabberID", "jabberRoom", "members", "parentCircle", "children"]
 if 'djangoldp_community' in settings.DJANGOLDP_PACKAGES:
     circle_fields += ['community']
 
@@ -33,6 +32,9 @@ if 'djangoldp_resource' in settings.DJANGOLDP_PACKAGES:
 if 'djangoldp_event' in settings.DJANGOLDP_PACKAGES:
     circle_fields += ['events']
 
+if 'djangoldp_fcpe' in settings.DJANGOLDP_PACKAGES:
+    circle_fields += ['space']
+
 
 class Circle(Model):
     name = models.CharField(max_length=255, blank=True, null=True, default='')
@@ -42,6 +44,8 @@ class Circle(Model):
     status = models.CharField(max_length=8, choices=STATUS_CHOICES, default='Public')
     owner = models.ForeignKey(settings.AUTH_USER_MODEL, related_name="owned_circles", on_delete=models.SET_NULL,
                               null=True, blank=True)
+    parentCircle = models.ForeignKey("self", on_delete=models.SET_NULL, null=True, blank=True, related_name='children',
+                                     help_text="A circle can optionally be nested within a parent")
     jabberID = models.CharField(max_length=255, blank=True, null=True, unique=True)
     jabberRoom = models.BooleanField(default=True)
 
