@@ -4,7 +4,6 @@ from datetime import datetime, timedelta
 
 from djangoldp.permissions import LDPPermissions
 
-from djangoldp.serializers import LDListMixin, LDPSerializer
 from rest_framework.test import APITestCase, APIClient
 from guardian.shortcuts import assign_perm
 
@@ -15,8 +14,6 @@ from djangoldp_circle.tests.utils import get_random_user
 class PermissionsTestCase(APITestCase):
     def setUp(self):
         self.client = APIClient()
-        LDListMixin.to_representation_cache.reset()
-        LDPSerializer.to_representation_cache.reset()
 
     def setUpLoggedInUser(self):
         self.user = get_random_user()
