@@ -33,14 +33,6 @@ class CircleMembersViewset(LDPViewSet):
 
         return False
 
-    def destroy(self, request, *args, **kwargs):
-        instance = self.get_object()
-
-        LDPSerializer.to_representation_cache.invalidate(instance.circle.urlid)
-        LDPSerializer.to_representation_cache.invalidate(instance.user.urlid)
-
-        return super().destroy(request, *args, **kwargs)
-
 
 class CirclesJoinableViewset(LDPViewSet):
 
